==> humhub-1.2.1.tar.gz: humhub-1.2.1/protected/humhub/modules/activity/messages/fr/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => 'Résumés par <strong>e-mail</strong>',
  'Activities' => 'Activités',
  'Daily' => 'Quotidien ',
  'E-Mail Summaries' => 'Résumés par e-mail',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'Des résumés sont envoyés par e-mail pour informer des activités récentes dans votre réseau. ',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'Des résumés sont envoyés aux utilisateurs par e-mail pour les informer des activités récentes dans votre réseau.',
  'Exclude spaces below from the mail summary' => 'Exclure les espaces suivants de la liste des résumés par e-mail',
  'Hourly' => 'Horaire',
  'Interval' => 'Intervalle',
  'Latest news' => 'Dernières nouvelles',
  'Never' => 'Jamais',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Sur cette page vous pouvez configurer le contenu et l\'intervalle de ces mises à jour par e-mail',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Sur cette page vous pouvez définir les préférences par défaut des utilisateurs. Ces préférences peuvent êtres modifiées par les utilisateurs sur leur page de paramètres de compte.',
  'Only include spaces below to the mail summary' => 'Inclure uniquement les espaces suivants aux résumés par e-mail',
  'Reset to defaults' => 'Réinitialiser les paramètres',
  'Spaces' => 'Espaces',
  'Weekly' => 'Hebdomadaire',
  'You will only receive an e-mail if there is something new.' => 'Vous recevrez un e-mail uniquement s\'il y a du nouveau.',
  'Your daily summary' => 'Votre résumé quotidien',
  'Your weekly summary' => 'Votre résumé hebdomadaire',
);

==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/activity/messages/fr/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => 'Résumés par <strong>e-mail</strong>',
  'Activities' => 'Activités',
  'Daily' => 'tous les jours',
  'E-Mail Summaries' => 'Résumés par e-mail',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'Des résumés sont envoyés par e-mail pour informer des activités récentes dans votre réseau. ',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'Des résumés sont envoyés aux utilisateurs par e-mail pour les informer des activités récentes dans votre réseau.',
  'Exclude spaces below from the mail summary' => 'Exclure les espaces suivants de la liste des résumés par e-mail',
  'Hourly' => 'toutes les heures',
  'Interval' => 'Intervalle',
  'Latest news' => 'Dernières nouvelles',
  'Never' => 'jamais',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Sur cette page vous pouvez configurer le contenu et l\'intervalle de ces mises à jour par e-mail',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Sur cette page vous pouvez définir les préférences par défaut des utilisateurs. Ces préférences peuvent êtres modifiées par les utilisateurs sur leur page de paramètres de compte.',
  'Only include spaces below to the mail summary' => 'Inclure uniquement les espaces suivants aux résumés par e-mail',
  'Reset to defaults' => 'Paramètres par défaut',
  'Spaces' => 'Espaces',
  'Weekly' => 'toutes les semaines',
  'You will only receive an e-mail if there is something new.' => 'Vous recevrez un e-mail uniquement si il y a du nouveau à vous communiquer.',
  'Your daily summary' => 'Votre résumé quotidien',
  'Your weekly summary' => 'Votre résumé hebdomadaire',
);
